pub enum Error {
ZeroThreshold,
ThresholdUnsatisfiable {
required: usize,
available: usize,
},
ThresholdNotMet {
required: usize,
satisfied: usize,
},
}Expand description
Threshold conditions verification errors.
Variants
ZeroThreshold
The threshold was zero.
ThresholdUnsatisfiable
The threshold exceeds the number of subconditions and can never be met.
Fields
ThresholdNotMet
Fewer than the required number of subconditions were satisfied.