#[non_exhaustive]pub enum AssetError {
Serialization(String),
Parsing(String),
ZeroAmount,
MissingId,
}Expand description
Errors related to asset parsing, validation, or formatting.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Serialization(String)
Failed to serialize an asset to bytes or JSON.
Parsing(String)
Failed to parse an asset from bytes or JSON.
ZeroAmount
A token or native amount was zero, which is not allowed.
MissingId
The contract address or mint for a fungible token was not provided.